import typing

import android.location
import android.net
import android.net.wifi
import android.net.wifi.aware
import android.os
import android.util
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class CivicLocationKeys(java.lang.Object):
    ADDITIONAL_CODE: typing.ClassVar[int] = ...
    APT: typing.ClassVar[int] = ...
    BOROUGH: typing.ClassVar[int] = ...
    BRANCH_ROAD_NAME: typing.ClassVar[int] = ...
    BUILDING: typing.ClassVar[int] = ...
    CITY: typing.ClassVar[int] = ...
    COUNTY: typing.ClassVar[int] = ...
    DESK: typing.ClassVar[int] = ...
    FLOOR: typing.ClassVar[int] = ...
    GROUP_OF_STREETS: typing.ClassVar[int] = ...
    HNO: typing.ClassVar[int] = ...
    HNS: typing.ClassVar[int] = ...
    LANGUAGE: typing.ClassVar[int] = ...
    LMK: typing.ClassVar[int] = ...
    LOC: typing.ClassVar[int] = ...
    NAM: typing.ClassVar[int] = ...
    NEIGHBORHOOD: typing.ClassVar[int] = ...
    PCN: typing.ClassVar[int] = ...
    POD: typing.ClassVar[int] = ...
    POSTAL_CODE: typing.ClassVar[int] = ...
    PO_BOX: typing.ClassVar[int] = ...
    PRD: typing.ClassVar[int] = ...
    PRIMARY_ROAD_NAME: typing.ClassVar[int] = ...
    ROAD_SECTION: typing.ClassVar[int] = ...
    ROOM: typing.ClassVar[int] = ...
    SCRIPT: typing.ClassVar[int] = ...
    STATE: typing.ClassVar[int] = ...
    STREET_NAME_POST_MODIFIER: typing.ClassVar[int] = ...
    STREET_NAME_PRE_MODIFIER: typing.ClassVar[int] = ...
    STS: typing.ClassVar[int] = ...
    SUBBRANCH_ROAD_NAME: typing.ClassVar[int] = ...
    TYPE_OF_PLACE: typing.ClassVar[int] = ...

class PasnConfig(android.os.Parcelable):
    AKM_FILS_EAP_SHA256: typing.ClassVar[int] = ...
    AKM_FILS_EAP_SHA384: typing.ClassVar[int] = ...
    AKM_FT_EAP_SHA256: typing.ClassVar[int] = ...
    AKM_FT_EAP_SHA384: typing.ClassVar[int] = ...
    AKM_FT_PSK_SHA256: typing.ClassVar[int] = ...
    AKM_FT_PSK_SHA384: typing.ClassVar[int] = ...
    AKM_NONE: typing.ClassVar[int] = ...
    AKM_PASN: typing.ClassVar[int] = ...
    AKM_SAE: typing.ClassVar[int] = ...
    CIPHER_CCMP_128: typing.ClassVar[int] = ...
    CIPHER_CCMP_256: typing.ClassVar[int] = ...
    CIPHER_GCMP_128: typing.ClassVar[int] = ...
    CIPHER_GCMP_256: typing.ClassVar[int] = ...
    CIPHER_NONE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PasnConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBaseAkms(self) -> int: ...
    def getCiphers(self) -> int: ...
    def getPasnComebackCookie(self) -> java.chaquopy.JavaArrayJByte: ...
    def getPassword(self) -> str: ...
    def getWifiSsid(self) -> android.net.wifi.WifiSsid: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, baseAkms: int | java.jint | java.lang.Integer, ciphers: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> PasnConfig: ...
        def setPasnComebackCookie(self, pasnComebackCookie: java.chaquopy.JavaArrayJByte, /) -> PasnConfig.Builder: ...
        def setPassword(self, password: str | java.lang.String, /) -> PasnConfig.Builder: ...
        def setWifiSsid(self, wifiSsid: android.net.wifi.WifiSsid, /) -> PasnConfig.Builder: ...

class RangingRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RangingRequest]] = ...
    SECURITY_MODE_OPEN: typing.ClassVar[int] = ...
    SECURITY_MODE_OPPORTUNISTIC: typing.ClassVar[int] = ...
    SECURITY_MODE_SECURE_AUTH: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def getDefaultRttBurstSize() -> int: ...
    @staticmethod
    def getMaxPeers() -> int: ...
    @staticmethod
    def getMaxRttBurstSize() -> int: ...
    @staticmethod
    def getMinRttBurstSize() -> int: ...
    def getRttBurstSize(self) -> int: ...
    def getSecurityMode(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addAccessPoint(self, apInfo: android.net.wifi.ScanResult, /) -> RangingRequest.Builder: ...
        def addAccessPoints(self, apInfos: java.util.List[android.net.wifi.ScanResult], /) -> RangingRequest.Builder: ...
        def addNon80211mcCapableAccessPoint(self, apInfo: android.net.wifi.ScanResult, /) -> RangingRequest.Builder: ...
        def addNon80211mcCapableAccessPoints(self, apInfos: java.util.List[android.net.wifi.ScanResult], /) -> RangingRequest.Builder: ...
        def addResponder(self, responder: ResponderConfig, /) -> RangingRequest.Builder: ...
        def addResponders(self, responders: java.util.List[ResponderConfig], /) -> RangingRequest.Builder: ...
        @typing.overload
        def addWifiAwarePeer(self, peerMacAddress: android.net.MacAddress, /) -> RangingRequest.Builder: ...
        @typing.overload
        def addWifiAwarePeer(self, peerHandle: android.net.wifi.aware.PeerHandle, /) -> RangingRequest.Builder: ...
        def build(self) -> RangingRequest: ...
        def setRttBurstSize(self, rttBurstSize: int | java.jint | java.lang.Integer, /) -> RangingRequest.Builder: ...
        def setSecurityMode(self, securityMode: int | java.jint | java.lang.Integer, /) -> RangingRequest.Builder: ...

class RangingResult(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RangingResult]] = ...
    STATUS_FAIL: typing.ClassVar[int] = ...
    STATUS_RESPONDER_DOES_NOT_SUPPORT_IEEE80211MC: typing.ClassVar[int] = ...
    STATUS_SUCCESS: typing.ClassVar[int] = ...
    UNSPECIFIED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def get80211azInitiatorTxLtfRepetitionsCount(self) -> int: ...
    def get80211azNumberOfRxSpatialStreams(self) -> int: ...
    def get80211azNumberOfTxSpatialStreams(self) -> int: ...
    def get80211azResponderTxLtfRepetitionsCount(self) -> int: ...
    def getDistanceMm(self) -> int: ...
    def getDistanceStdDevMm(self) -> int: ...
    def getLci(self) -> java.chaquopy.JavaArrayJByte: ...
    def getLcr(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMacAddress(self) -> android.net.MacAddress | None: ...
    def getMaxTimeBetweenNtbMeasurementsMicros(self) -> int: ...
    def getMeasurementBandwidth(self) -> int: ...
    def getMeasurementChannelFrequencyMHz(self) -> int: ...
    def getMinTimeBetweenNtbMeasurementsMicros(self) -> int: ...
    def getNumAttemptedMeasurements(self) -> int: ...
    def getNumSuccessfulMeasurements(self) -> int: ...
    def getPasnComebackAfterMillis(self) -> int: ...
    def getPasnComebackCookie(self) -> java.chaquopy.JavaArrayJByte: ...
    def getPeerHandle(self) -> android.net.wifi.aware.PeerHandle | None: ...
    def getRangingTimestampMillis(self) -> int: ...
    def getRssi(self) -> int: ...
    def getSecureHeLtfProtocolVersion(self) -> int: ...
    def getStatus(self) -> int: ...
    def getUnverifiedResponderLocation(self) -> ResponderLocation | None: ...
    def hashCode(self) -> int: ...
    def is80211azNtbMeasurement(self) -> bool: ...
    def is80211mcMeasurement(self) -> bool: ...
    def isRangingAuthenticated(self) -> bool: ...
    def isRangingFrameProtected(self) -> bool: ...
    def isSecureHeLtfEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> RangingResult: ...
        def set80211azInitiatorTxLtfRepetitionsCount(self, i2rTxLtfRepetitions: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def set80211azNtbMeasurement(self, is80211azNtbMeasurement: bool | java.jboolean | java.lang.Boolean, /) -> RangingResult.Builder: ...
        def set80211azNumberOfRxSpatialStreams(self, numRxSpatialStreams: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def set80211azNumberOfTxSpatialStreams(self, numTxSpatialStreams: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def set80211azResponderTxLtfRepetitionsCount(self, r2iTxLtfRepetitions: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def set80211mcMeasurement(self, is80211mcMeasurement: bool | java.jboolean | java.lang.Boolean, /) -> RangingResult.Builder: ...
        def setDistanceMm(self, distanceMm: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setDistanceStdDevMm(self, distanceStdDevMm: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setLci(self, lci: java.chaquopy.JavaArrayJByte, /) -> RangingResult.Builder: ...
        def setLcr(self, lcr: java.chaquopy.JavaArrayJByte, /) -> RangingResult.Builder: ...
        def setMacAddress(self, macAddress: android.net.MacAddress, /) -> RangingResult.Builder: ...
        def setMaxTimeBetweenNtbMeasurementsMicros(self, ntbMaxMeasurementTime: int | java.jlong | java.lang.Long, /) -> RangingResult.Builder: ...
        def setMeasurementBandwidth(self, measurementBandwidth: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setMeasurementChannelFrequencyMHz(self, frequencyMHz: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setMinTimeBetweenNtbMeasurementsMicros(self, ntbMinMeasurementTime: int | java.jlong | java.lang.Long, /) -> RangingResult.Builder: ...
        def setNumAttemptedMeasurements(self, numAttemptedMeasurements: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setNumSuccessfulMeasurements(self, numSuccessfulMeasurements: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setPasnComebackAfterMillis(self, comebackAfterMillis: int | java.jlong | java.lang.Long, /) -> RangingResult.Builder: ...
        def setPasnComebackCookie(self, pasnComebackCookie: java.chaquopy.JavaArrayJByte, /) -> RangingResult.Builder: ...
        def setPeerHandle(self, peerHandle: android.net.wifi.aware.PeerHandle, /) -> RangingResult.Builder: ...
        def setRangingAuthenticated(self, isRangingAuthenticated: bool | java.jboolean | java.lang.Boolean, /) -> RangingResult.Builder: ...
        def setRangingFrameProtected(self, isRangingFrameProtected: bool | java.jboolean | java.lang.Boolean, /) -> RangingResult.Builder: ...
        def setRangingTimestampMillis(self, timestamp: int | java.jlong | java.lang.Long, /) -> RangingResult.Builder: ...
        def setRssi(self, rssi: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setSecureHeLtfEnabled(self, isSecureHeLtfEnabled: bool | java.jboolean | java.lang.Boolean, /) -> RangingResult.Builder: ...
        def setSecureHeLtfProtocolVersion(self, secureHeLtfProtocolVersion: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setStatus(self, status: int | java.jint | java.lang.Integer, /) -> RangingResult.Builder: ...
        def setUnverifiedResponderLocation(self, responderLocation: ResponderLocation, /) -> RangingResult.Builder: ...

class RangingResultCallback(java.lang.Object):
    STATUS_CODE_FAIL: typing.ClassVar[int] = ...
    STATUS_CODE_FAIL_RTT_NOT_AVAILABLE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onRangingFailure(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRangingResults(self, arg1: java.util.List[RangingResult], /) -> None: ...

class ResponderConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ResponderConfig]] = ...
    RESPONDER_AP: typing.ClassVar[int] = ...
    RESPONDER_STA: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromScanResult(scanResult: android.net.wifi.ScanResult, /) -> ResponderConfig: ...
    def getCenterFreq0Mhz(self) -> int: ...
    def getCenterFreq1Mhz(self) -> int: ...
    def getChannelWidth(self) -> int: ...
    def getFrequencyMhz(self) -> int: ...
    def getMacAddress(self) -> android.net.MacAddress | None: ...
    def getPreamble(self) -> int: ...
    def getResponderType(self) -> int: ...
    def getSecureRangingConfig(self) -> SecureRangingConfig: ...
    def hashCode(self) -> int: ...
    def is80211azNtbSupported(self) -> bool: ...
    def is80211mcSupported(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> ResponderConfig: ...
        def set80211azNtbSupported(self, supports80211azNtb: bool | java.jboolean | java.lang.Boolean, /) -> ResponderConfig.Builder: ...
        def set80211mcSupported(self, supports80211mc: bool | java.jboolean | java.lang.Boolean, /) -> ResponderConfig.Builder: ...
        def setCenterFreq0Mhz(self, centerFreq0: int | java.jint | java.lang.Integer, /) -> ResponderConfig.Builder: ...
        def setCenterFreq1Mhz(self, centerFreq1: int | java.jint | java.lang.Integer, /) -> ResponderConfig.Builder: ...
        def setChannelWidth(self, channelWidth: int | java.jint | java.lang.Integer, /) -> ResponderConfig.Builder: ...
        def setFrequencyMhz(self, frequency: int | java.jint | java.lang.Integer, /) -> ResponderConfig.Builder: ...
        def setMacAddress(self, macAddress: android.net.MacAddress, /) -> ResponderConfig.Builder: ...
        def setPreamble(self, preamble: int | java.jint | java.lang.Integer, /) -> ResponderConfig.Builder: ...
        def setResponderType(self, responderType: int | java.jint | java.lang.Integer, /) -> ResponderConfig.Builder: ...
        def setSecureRangingConfig(self, secureRangingConfig: SecureRangingConfig, /) -> ResponderConfig.Builder: ...

class ResponderLocation(android.os.Parcelable):
    ALTITUDE_FLOORS: typing.ClassVar[int] = ...
    ALTITUDE_METERS: typing.ClassVar[int] = ...
    ALTITUDE_UNDEFINED: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ResponderLocation]] = ...
    DATUM_NAD83_MLLW: typing.ClassVar[int] = ...
    DATUM_NAD83_NAV88: typing.ClassVar[int] = ...
    DATUM_UNDEFINED: typing.ClassVar[int] = ...
    DATUM_WGS84: typing.ClassVar[int] = ...
    LCI_VERSION_1: typing.ClassVar[int] = ...
    LOCATION_FIXED: typing.ClassVar[int] = ...
    LOCATION_MOVEMENT_UNKNOWN: typing.ClassVar[int] = ...
    LOCATION_RESERVED: typing.ClassVar[int] = ...
    LOCATION_VARIABLE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAltitude(self) -> float: ...
    def getAltitudeType(self) -> int: ...
    def getAltitudeUncertainty(self) -> float: ...
    def getColocatedBssids(self) -> java.util.List[android.net.MacAddress]: ...
    def getDatum(self) -> int: ...
    def getExpectedToMove(self) -> int: ...
    def getFloorNumber(self) -> float: ...
    def getHeightAboveFloorMeters(self) -> float: ...
    def getHeightAboveFloorUncertaintyMeters(self) -> float: ...
    def getLatitude(self) -> float: ...
    def getLatitudeUncertainty(self) -> float: ...
    def getLciVersion(self) -> int: ...
    def getLongitude(self) -> float: ...
    def getLongitudeUncertainty(self) -> float: ...
    def getMapImageMimeType(self) -> str | None: ...
    def getMapImageUri(self) -> android.net.Uri | None: ...
    def getRegisteredLocationAgreementIndication(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isLciSubelementValid(self) -> bool: ...
    def isZaxisSubelementValid(self) -> bool: ...
    def toCivicLocationAddress(self) -> android.location.Address | None: ...
    def toCivicLocationSparseArray(self) -> android.util.SparseArray[java.lang.String] | None: ...
    def toLocation(self) -> android.location.Location: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SecureRangingConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SecureRangingConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPasnConfig(self) -> PasnConfig: ...
    def hashCode(self) -> int: ...
    def isRangingFrameProtectionEnabled(self) -> bool: ...
    def isSecureHeLtfEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, pasnConfig: PasnConfig, /) -> None: ...
        def build(self) -> SecureRangingConfig: ...
        def setRangingFrameProtectionEnabled(self, enableRangingFrameProtection: bool | java.jboolean | java.lang.Boolean, /) -> SecureRangingConfig.Builder: ...
        def setSecureHeLtfEnabled(self, enableSecureHeLtf: bool | java.jboolean | java.lang.Boolean, /) -> SecureRangingConfig.Builder: ...

class WifiRttManager(java.lang.Object):
    ACTION_WIFI_RTT_STATE_CHANGED: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_LCI: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_LCR: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_NTB_INITIATOR: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_ONE_SIDED_RTT: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_RANGING_FRAME_PROTECTION_SUPPORTED: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_SECURE_HE_LTF_SUPPORTED: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_BOOLEAN_STA_RESPONDER: typing.ClassVar[str] = ...
    CHARACTERISTICS_KEY_INT_MAX_SUPPORTED_SECURE_HE_LTF_PROTO_VERSION: typing.ClassVar[str] = ...
    def getRttCharacteristics(self) -> android.os.Bundle: ...
    def isAvailable(self) -> bool: ...
    def startRanging(self, request: RangingRequest, executor: java.util.concurrent.Executor, callback: RangingResultCallback, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.net
import java.nio
import java.security
import java.security.cert
import java.util
import java.util.function
import javax.net
import javax.security.cert

class CertPathTrustManagerParameters(ManagerFactoryParameters):
    def __init__(self, parameters: java.security.cert.CertPathParameters, /) -> None: ...
    def getParameters(self) -> java.security.cert.CertPathParameters: ...

class ExtendedSSLSession(SSLSession):
    def __init__(self) -> None: ...
    def getLocalSupportedSignatureAlgorithms(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getPeerSupportedSignatureAlgorithms(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getRequestedServerNames(self) -> java.util.List[SNIServerName]: ...

class HandshakeCompletedEvent(java.util.EventObject):
    def __init__(self, sock: SSLSocket, s: SSLSession, /) -> None: ...
    def getCipherSuite(self) -> str: ...
    def getLocalCertificates(self) -> java.chaquopy.JavaArray[java.security.cert.Certificate]: ...
    def getLocalPrincipal(self) -> java.security.Principal: ...
    def getPeerCertificateChain(self) -> java.chaquopy.JavaArray[javax.security.cert.X509Certificate]: ...
    def getPeerCertificates(self) -> java.chaquopy.JavaArray[java.security.cert.Certificate]: ...
    def getPeerPrincipal(self) -> java.security.Principal: ...
    def getSession(self) -> SSLSession: ...
    def getSocket(self) -> SSLSocket: ...

class HandshakeCompletedListener(java.util.EventListener):
    def handshakeCompleted(self, arg1: HandshakeCompletedEvent, /) -> None: ...

class HostnameVerifier(java.lang.Object):
    def verify(self, arg1: str | java.lang.String, arg2: SSLSession, /) -> bool: ...

class HttpsURLConnection(java.net.HttpURLConnection):
    hostnameVerifier: HostnameVerifier = ...
    def __init__(self, url: java.net.URL, /) -> None: ...
    def getCipherSuite(self) -> str: ...
    @staticmethod
    def getDefaultHostnameVerifier() -> HostnameVerifier: ...
    @staticmethod
    def getDefaultSSLSocketFactory() -> SSLSocketFactory: ...
    def getHostnameVerifier(self) -> HostnameVerifier: ...
    def getLocalCertificates(self) -> java.chaquopy.JavaArray[java.security.cert.Certificate]: ...
    def getLocalPrincipal(self) -> java.security.Principal: ...
    def getPeerPrincipal(self) -> java.security.Principal: ...
    def getSSLSocketFactory(self) -> SSLSocketFactory: ...
    def getServerCertificates(self) -> java.chaquopy.JavaArray[java.security.cert.Certificate]: ...
    @staticmethod
    def setDefaultHostnameVerifier(v: HostnameVerifier, /) -> None: ...
    @staticmethod
    def setDefaultSSLSocketFactory(sf: SSLSocketFactory, /) -> None: ...
    def setHostnameVerifier(self, v: HostnameVerifier, /) -> None: ...
    def setSSLSocketFactory(self, sf: SSLSocketFactory, /) -> None: ...

class KeyManager(java.lang.Object): ...

class KeyManagerFactory(java.lang.Object):
    def __init__(self, factorySpi: KeyManagerFactorySpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def getAlgorithm(self) -> str: ...
    @staticmethod
    def getDefaultAlgorithm() -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> KeyManagerFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> KeyManagerFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> KeyManagerFactory: ...
    def getKeyManagers(self) -> java.chaquopy.JavaArray[KeyManager]: ...
    def getProvider(self) -> java.security.Provider: ...
    @typing.overload
    def init(self, spec: ManagerFactoryParameters, /) -> None: ...
    @typing.overload
    def init(self, ks: java.security.KeyStore, password: java.chaquopy.JavaArrayJChar, /) -> None: ...

class KeyManagerFactorySpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineGetKeyManagers(self) -> java.chaquopy.JavaArray[KeyManager]: ...
    @typing.overload
    def engineInit(self, arg1: ManagerFactoryParameters, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: java.security.KeyStore, arg2: java.chaquopy.JavaArrayJChar, /) -> None: ...

class KeyStoreBuilderParameters(ManagerFactoryParameters):
    @typing.overload
    def __init__(self, builder: java.security.KeyStore.Builder, /) -> None: ...
    @typing.overload
    def __init__(self, parameters: java.util.List[java.security.KeyStore.Builder], /) -> None: ...
    def getParameters(self) -> java.util.List[java.security.KeyStore.Builder]: ...

class ManagerFactoryParameters(java.lang.Object): ...

class SNIHostName(SNIServerName):
    @typing.overload
    def __init__(self, hostname: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, encoded: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @staticmethod
    def createSNIMatcher(regex: str | java.lang.String, /) -> SNIMatcher: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAsciiName(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class SNIMatcher(java.lang.Object):
    def __init__(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def getType(self) -> int: ...
    def matches(self, arg1: SNIServerName, /) -> bool: ...

class SNIServerName(java.lang.Object):
    def __init__(self, type: int | java.jint | java.lang.Integer, encoded: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class SSLContext(java.lang.Object):
    def __init__(self, contextSpi: SSLContextSpi, provider: java.security.Provider, protocol: str | java.lang.String, /) -> None: ...
    @typing.overload
    def createSSLEngine(self) -> SSLEngine: ...
    @typing.overload
    def createSSLEngine(self, peerHost: str | java.lang.String, peerPort: int | java.jint | java.lang.Integer, /) -> SSLEngine: ...
    def getClientSessionContext(self) -> SSLSessionContext: ...
    @staticmethod
    def getDefault() -> SSLContext: ...
    def getDefaultSSLParameters(self) -> SSLParameters: ...
    @typing.overload
    @staticmethod
    def getInstance(protocol: str | java.lang.String, /) -> SSLContext: ...
    @typing.overload
    @staticmethod
    def getInstance(protocol: str | java.lang.String, provider: str | java.lang.String, /) -> SSLContext: ...
    @typing.overload
    @staticmethod
    def getInstance(protocol: str | java.lang.String, provider: java.security.Provider, /) -> SSLContext: ...
    def getProtocol(self) -> str: ...
    def getProvider(self) -> java.security.Provider: ...
    def getServerSessionContext(self) -> SSLSessionContext: ...
    def getServerSocketFactory(self) -> SSLServerSocketFactory: ...
    def getSocketFactory(self) -> SSLSocketFactory: ...
    def getSupportedSSLParameters(self) -> SSLParameters: ...
    def init(self, km: java.chaquopy.JavaArray[KeyManager], tm: java.chaquopy.JavaArray[TrustManager], random: java.security.SecureRandom, /) -> None: ...
    @staticmethod
    def setDefault(context: SSLContext, /) -> None: ...

class SSLContextSpi(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def engineCreateSSLEngine(self) -> SSLEngine: ...
    @typing.overload
    def engineCreateSSLEngine(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> SSLEngine: ...
    def engineGetClientSessionContext(self) -> SSLSessionContext: ...
    def engineGetDefaultSSLParameters(self) -> SSLParameters: ...
    def engineGetServerSessionContext(self) -> SSLSessionContext: ...
    def engineGetServerSocketFactory(self) -> SSLServerSocketFactory: ...
    def engineGetSocketFactory(self) -> SSLSocketFactory: ...
    def engineGetSupportedSSLParameters(self) -> SSLParameters: ...
    def engineInit(self, arg1: java.chaquopy.JavaArray[KeyManager], arg2: java.chaquopy.JavaArray[TrustManager], arg3: java.security.SecureRandom, /) -> None: ...

class SSLEngine(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, peerHost: str | java.lang.String, peerPort: int | java.jint | java.lang.Integer, /) -> None: ...
    def beginHandshake(self) -> None: ...
    def closeInbound(self) -> None: ...
    def closeOutbound(self) -> None: ...
    def getApplicationProtocol(self) -> str: ...
    def getDelegatedTask(self) -> java.lang.Runnable: ...
    def getEnableSessionCreation(self) -> bool: ...
    def getEnabledCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getEnabledProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getHandshakeApplicationProtocol(self) -> str: ...
    def getHandshakeApplicationProtocolSelector(self) -> java.util.function.BiFunction[SSLEngine, java.util.List[java.lang.String], java.lang.String]: ...
    def getHandshakeSession(self) -> SSLSession: ...
    def getHandshakeStatus(self) -> SSLEngineResult.HandshakeStatus: ...
    def getNeedClientAuth(self) -> bool: ...
    def getPeerHost(self) -> str: ...
    def getPeerPort(self) -> int: ...
    def getSSLParameters(self) -> SSLParameters: ...
    def getSession(self) -> SSLSession: ...
    def getSupportedCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSupportedProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getUseClientMode(self) -> bool: ...
    def getWantClientAuth(self) -> bool: ...
    def isInboundDone(self) -> bool: ...
    def isOutboundDone(self) -> bool: ...
    def setEnableSessionCreation(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEnabledCipherSuites(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setEnabledProtocols(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setHandshakeApplicationProtocolSelector(self, selector: java.util.function.BiFunction[SSLEngine, java.util.List[java.lang.String], java.lang.String], /) -> None: ...
    def setNeedClientAuth(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSSLParameters(self, params: SSLParameters, /) -> None: ...
    def setUseClientMode(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWantClientAuth(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def unwrap(self, src: java.nio.ByteBuffer, dst: java.nio.ByteBuffer, /) -> SSLEngineResult: ...
    @typing.overload
    def unwrap(self, src: java.nio.ByteBuffer, dsts: java.chaquopy.JavaArray[java.nio.ByteBuffer], /) -> SSLEngineResult: ...
    @typing.overload
    def unwrap(self, arg1: java.nio.ByteBuffer, arg2: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> SSLEngineResult: ...
    @typing.overload
    def wrap(self, src: java.nio.ByteBuffer, dst: java.nio.ByteBuffer, /) -> SSLEngineResult: ...
    @typing.overload
    def wrap(self, srcs: java.chaquopy.JavaArray[java.nio.ByteBuffer], dst: java.nio.ByteBuffer, /) -> SSLEngineResult: ...
    @typing.overload
    def wrap(self, arg1: java.chaquopy.JavaArray[java.nio.ByteBuffer], arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.ByteBuffer, /) -> SSLEngineResult: ...

class SSLEngineResult(java.lang.Object):
    def __init__(self, status: SSLEngineResult.Status, handshakeStatus: SSLEngineResult.HandshakeStatus, bytesConsumed: int | java.jint | java.lang.Integer, bytesProduced: int | java.jint | java.lang.Integer, /) -> None: ...
    def bytesConsumed(self) -> int: ...
    def bytesProduced(self) -> int: ...
    def getHandshakeStatus(self) -> SSLEngineResult.HandshakeStatus: ...
    def getStatus(self) -> SSLEngineResult.Status: ...
    def toString(self) -> str: ...

    class Status(java.lang.Enum[SSLEngineResult.Status]):
        BUFFER_OVERFLOW: typing.ClassVar[SSLEngineResult.Status] = ...
        BUFFER_UNDERFLOW: typing.ClassVar[SSLEngineResult.Status] = ...
        CLOSED: typing.ClassVar[SSLEngineResult.Status] = ...
        OK: typing.ClassVar[SSLEngineResult.Status] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> SSLEngineResult.Status: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[SSLEngineResult.Status]: ...

    class HandshakeStatus(java.lang.Enum[SSLEngineResult.HandshakeStatus]):
        FINISHED: typing.ClassVar[SSLEngineResult.HandshakeStatus] = ...
        NEED_TASK: typing.ClassVar[SSLEngineResult.HandshakeStatus] = ...
        NEED_UNWRAP: typing.ClassVar[SSLEngineResult.HandshakeStatus] = ...
        NEED_WRAP: typing.ClassVar[SSLEngineResult.HandshakeStatus] = ...
        NOT_HANDSHAKING: typing.ClassVar[SSLEngineResult.HandshakeStatus] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> SSLEngineResult.HandshakeStatus: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[SSLEngineResult.HandshakeStatus]: ...

class SSLException(java.io.IOException):
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class SSLHandshakeException(SSLException):
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class SSLKeyException(SSLException):
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class SSLParameters(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, cipherSuites: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def __init__(self, cipherSuites: java.chaquopy.JavaArray[java.lang.String], protocols: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getAlgorithmConstraints(self) -> java.security.AlgorithmConstraints: ...
    def getApplicationProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getEndpointIdentificationAlgorithm(self) -> str: ...
    def getNeedClientAuth(self) -> bool: ...
    def getProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSNIMatchers(self) -> java.util.Collection[SNIMatcher]: ...
    def getServerNames(self) -> java.util.List[SNIServerName]: ...
    def getUseCipherSuitesOrder(self) -> bool: ...
    def getWantClientAuth(self) -> bool: ...
    def setAlgorithmConstraints(self, constraints: java.security.AlgorithmConstraints, /) -> None: ...
    def setApplicationProtocols(self, protocols: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setCipherSuites(self, cipherSuites: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setEndpointIdentificationAlgorithm(self, algorithm: str | java.lang.String, /) -> None: ...
    def setNeedClientAuth(self, needClientAuth: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProtocols(self, protocols: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setSNIMatchers(self, matchers: java.util.Collection[SNIMatcher], /) -> None: ...
    def setServerNames(self, serverNames: java.util.List[SNIServerName], /) -> None: ...
    def setUseCipherSuitesOrder(self, honorOrder: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWantClientAuth(self, wantClientAuth: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class SSLPeerUnverifiedException(SSLException):
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class SSLPermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...

class SSLProtocolException(SSLException):
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class SSLServerSocket(java.net.ServerSocket):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, port: int | java.jint | java.lang.Integer, backlog: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, port: int | java.jint | java.lang.Integer, backlog: int | java.jint | java.lang.Integer, address: java.net.InetAddress, /) -> None: ...
    def getEnableSessionCreation(self) -> bool: ...
    def getEnabledCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getEnabledProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getNeedClientAuth(self) -> bool: ...
    def getSSLParameters(self) -> SSLParameters: ...
    def getSupportedCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSupportedProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getUseClientMode(self) -> bool: ...
    def getWantClientAuth(self) -> bool: ...
    def setEnableSessionCreation(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEnabledCipherSuites(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setEnabledProtocols(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setNeedClientAuth(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSSLParameters(self, params: SSLParameters, /) -> None: ...
    def setUseClientMode(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWantClientAuth(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toString(self) -> str: ...

class SSLServerSocketFactory(javax.net.ServerSocketFactory):
    def __init__(self) -> None: ...
    @staticmethod
    def getDefault() -> javax.net.ServerSocketFactory: ...
    def getDefaultCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSupportedCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class SSLSession(java.lang.Object):
    def getApplicationBufferSize(self) -> int: ...
    def getCipherSuite(self) -> str: ...
    def getCreationTime(self) -> int: ...
    def getId(self) -> java.chaquopy.JavaArrayJByte: ...
    def getLastAccessedTime(self) -> int: ...
    def getLocalCertificates(self) -> java.chaquopy.JavaArray[java.security.cert.Certificate]: ...
    def getLocalPrincipal(self) -> java.security.Principal: ...
    def getPacketBufferSize(self) -> int: ...
    def getPeerCertificateChain(self) -> java.chaquopy.JavaArray[javax.security.cert.X509Certificate]: ...
    def getPeerCertificates(self) -> java.chaquopy.JavaArray[java.security.cert.Certificate]: ...
    def getPeerHost(self) -> str: ...
    def getPeerPort(self) -> int: ...
    def getPeerPrincipal(self) -> java.security.Principal: ...
    def getProtocol(self) -> str: ...
    def getSessionContext(self) -> SSLSessionContext: ...
    def getValue(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getValueNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def invalidate(self) -> None: ...
    def isValid(self) -> bool: ...
    def putValue(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    def removeValue(self, arg1: str | java.lang.String, /) -> None: ...

class SSLSessionBindingEvent(java.util.EventObject):
    def __init__(self, session: SSLSession, name: str | java.lang.String, /) -> None: ...
    def getName(self) -> str: ...
    def getSession(self) -> SSLSession: ...

class SSLSessionBindingListener(java.util.EventListener):
    def valueBound(self, arg1: SSLSessionBindingEvent, /) -> None: ...
    def valueUnbound(self, arg1: SSLSessionBindingEvent, /) -> None: ...

class SSLSessionContext(java.lang.Object):
    def getIds(self) -> java.util.Enumeration[java.chaquopy.JavaArrayJByte]: ...
    def getSession(self, arg1: java.chaquopy.JavaArrayJByte, /) -> SSLSession: ...
    def getSessionCacheSize(self) -> int: ...
    def getSessionTimeout(self) -> int: ...
    def setSessionCacheSize(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSessionTimeout(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class SSLSocket(java.net.Socket):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, address: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, clientAddress: java.net.InetAddress, clientPort: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, address: java.net.InetAddress, port: int | java.jint | java.lang.Integer, clientAddress: java.net.InetAddress, clientPort: int | java.jint | java.lang.Integer, /) -> None: ...
    def addHandshakeCompletedListener(self, arg1: HandshakeCompletedListener, /) -> None: ...
    def getApplicationProtocol(self) -> str: ...
    def getEnableSessionCreation(self) -> bool: ...
    def getEnabledCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getEnabledProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getHandshakeApplicationProtocol(self) -> str: ...
    def getHandshakeApplicationProtocolSelector(self) -> java.util.function.BiFunction[SSLSocket, java.util.List[java.lang.String], java.lang.String]: ...
    def getHandshakeSession(self) -> SSLSession: ...
    def getNeedClientAuth(self) -> bool: ...
    def getSSLParameters(self) -> SSLParameters: ...
    def getSession(self) -> SSLSession: ...
    def getSupportedCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSupportedProtocols(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getUseClientMode(self) -> bool: ...
    def getWantClientAuth(self) -> bool: ...
    def removeHandshakeCompletedListener(self, arg1: HandshakeCompletedListener, /) -> None: ...
    def setEnableSessionCreation(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEnabledCipherSuites(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setEnabledProtocols(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setHandshakeApplicationProtocolSelector(self, selector: java.util.function.BiFunction[SSLSocket, java.util.List[java.lang.String], java.lang.String], /) -> None: ...
    def setNeedClientAuth(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSSLParameters(self, params: SSLParameters, /) -> None: ...
    def setUseClientMode(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWantClientAuth(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startHandshake(self) -> None: ...
    def toString(self) -> str: ...

class SSLSocketFactory(javax.net.SocketFactory):
    def __init__(self) -> None: ...
    def createSocket(self, arg1: java.net.Socket, arg2: str | java.lang.String, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, /) -> java.net.Socket: ...
    @staticmethod
    def getDefault() -> javax.net.SocketFactory: ...
    def getDefaultCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSupportedCipherSuites(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class StandardConstants(java.lang.Object):
    SNI_HOST_NAME: typing.ClassVar[int] = ...

class TrustManager(java.lang.Object): ...

class TrustManagerFactory(java.lang.Object):
    def __init__(self, factorySpi: TrustManagerFactorySpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def getAlgorithm(self) -> str: ...
    @staticmethod
    def getDefaultAlgorithm() -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> TrustManagerFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> TrustManagerFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> TrustManagerFactory: ...
    def getProvider(self) -> java.security.Provider: ...
    def getTrustManagers(self) -> java.chaquopy.JavaArray[TrustManager]: ...
    @typing.overload
    def init(self, ks: java.security.KeyStore, /) -> None: ...
    @typing.overload
    def init(self, spec: ManagerFactoryParameters, /) -> None: ...

class TrustManagerFactorySpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineGetTrustManagers(self) -> java.chaquopy.JavaArray[TrustManager]: ...
    @typing.overload
    def engineInit(self, arg1: java.security.KeyStore, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: ManagerFactoryParameters, /) -> None: ...

class X509ExtendedKeyManager(X509KeyManager):
    def __init__(self) -> None: ...
    def chooseEngineClientAlias(self, keyType: java.chaquopy.JavaArray[java.lang.String], issuers: java.chaquopy.JavaArray[java.security.Principal], engine: SSLEngine, /) -> str: ...
    def chooseEngineServerAlias(self, keyType: str | java.lang.String, issuers: java.chaquopy.JavaArray[java.security.Principal], engine: SSLEngine, /) -> str: ...

class X509ExtendedTrustManager(X509TrustManager):
    def __init__(self) -> None: ...
    @typing.overload
    def checkClientTrusted(self, arg1: java.chaquopy.JavaArray[java.security.cert.X509Certificate], arg2: str | java.lang.String, arg3: java.net.Socket, /) -> None: ...
    @typing.overload
    def checkClientTrusted(self, arg1: java.chaquopy.JavaArray[java.security.cert.X509Certificate], arg2: str | java.lang.String, arg3: SSLEngine, /) -> None: ...
    @typing.overload
    def checkServerTrusted(self, arg1: java.chaquopy.JavaArray[java.security.cert.X509Certificate], arg2: str | java.lang.String, arg3: java.net.Socket, /) -> None: ...
    @typing.overload
    def checkServerTrusted(self, arg1: java.chaquopy.JavaArray[java.security.cert.X509Certificate], arg2: str | java.lang.String, arg3: SSLEngine, /) -> None: ...

class X509KeyManager(KeyManager):
    def chooseClientAlias(self, arg1: java.chaquopy.JavaArray[java.lang.String], arg2: java.chaquopy.JavaArray[java.security.Principal], arg3: java.net.Socket, /) -> str: ...
    def chooseServerAlias(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArray[java.security.Principal], arg3: java.net.Socket, /) -> str: ...
    def getCertificateChain(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.security.cert.X509Certificate]: ...
    def getClientAliases(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArray[java.security.Principal], /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getPrivateKey(self, arg1: str | java.lang.String, /) -> java.security.PrivateKey: ...
    def getServerAliases(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArray[java.security.Principal], /) -> java.chaquopy.JavaArray[java.lang.String]: ...

class X509TrustManager(TrustManager):
    def checkClientTrusted(self, arg1: java.chaquopy.JavaArray[java.security.cert.X509Certificate], arg2: str | java.lang.String, /) -> None: ...
    def checkServerTrusted(self, arg1: java.chaquopy.JavaArray[java.security.cert.X509Certificate], arg2: str | java.lang.String, /) -> None: ...
    def getAcceptedIssuers(self) -> java.chaquopy.JavaArray[java.security.cert.X509Certificate]: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.util

class BigDecimal(java.lang.Comparable[BigDecimal], java.lang.Number):
    ONE: typing.ClassVar[BigDecimal] = ...
    ROUND_CEILING: typing.ClassVar[int] = ...
    ROUND_DOWN: typing.ClassVar[int] = ...
    ROUND_FLOOR: typing.ClassVar[int] = ...
    ROUND_HALF_DOWN: typing.ClassVar[int] = ...
    ROUND_HALF_EVEN: typing.ClassVar[int] = ...
    ROUND_HALF_UP: typing.ClassVar[int] = ...
    ROUND_UNNECESSARY: typing.ClassVar[int] = ...
    ROUND_UP: typing.ClassVar[int] = ...
    TEN: typing.ClassVar[BigDecimal] = ...
    ZERO: typing.ClassVar[BigDecimal] = ...
    @typing.overload
    def __init__(self, val: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def __init__(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, val: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, val: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, val: BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def __init__(self, val: float | java.jdouble | java.lang.Double, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, val: int | java.jint | java.lang.Integer, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, val: int | java.jlong | java.lang.Long, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, val: str | java.lang.String, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, unscaledVal: BigInteger, scale: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, val: BigInteger, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.chaquopy.JavaArrayJChar, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, unscaledVal: BigInteger, scale: int | java.jint | java.lang.Integer, mc: MathContext, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, mc: MathContext, /) -> None: ...
    @typing.overload
    def abs(self) -> BigDecimal: ...
    @typing.overload
    def abs(self, mc: MathContext, /) -> BigDecimal: ...
    @typing.overload
    def add(self, augend: BigDecimal, /) -> BigDecimal: ...
    @typing.overload
    def add(self, augend: BigDecimal, mc: MathContext, /) -> BigDecimal: ...
    def byteValueExact(self) -> int: ...
    def compareTo(self, val: BigDecimal, /) -> int: ...
    @typing.overload
    def divide(self, divisor: BigDecimal, /) -> BigDecimal: ...
    @typing.overload
    def divide(self, divisor: BigDecimal, roundingMode: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def divide(self, divisor: BigDecimal, mc: MathContext, /) -> BigDecimal: ...
    @typing.overload
    def divide(self, divisor: BigDecimal, roundingMode: RoundingMode, /) -> BigDecimal: ...
    @typing.overload
    def divide(self, divisor: BigDecimal, scale: int | java.jint | java.lang.Integer, roundingMode: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def divide(self, divisor: BigDecimal, scale: int | java.jint | java.lang.Integer, roundingMode: RoundingMode, /) -> BigDecimal: ...
    @typing.overload
    def divideAndRemainder(self, divisor: BigDecimal, /) -> java.chaquopy.JavaArray[BigDecimal]: ...
    @typing.overload
    def divideAndRemainder(self, divisor: BigDecimal, mc: MathContext, /) -> java.chaquopy.JavaArray[BigDecimal]: ...
    @typing.overload
    def divideToIntegralValue(self, divisor: BigDecimal, /) -> BigDecimal: ...
    @typing.overload
    def divideToIntegralValue(self, divisor: BigDecimal, mc: MathContext, /) -> BigDecimal: ...
    def doubleValue(self) -> float: ...
    def equals(self, x: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def floatValue(self) -> float: ...
    def hashCode(self) -> int: ...
    def intValue(self) -> int: ...
    def intValueExact(self) -> int: ...
    def longValue(self) -> int: ...
    def longValueExact(self) -> int: ...
    def max(self, val: BigDecimal, /) -> BigDecimal: ...
    def min(self, val: BigDecimal, /) -> BigDecimal: ...
    def movePointLeft(self, n: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    def movePointRight(self, n: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def multiply(self, multiplicand: BigDecimal, /) -> BigDecimal: ...
    @typing.overload
    def multiply(self, multiplicand: BigDecimal, mc: MathContext, /) -> BigDecimal: ...
    @typing.overload
    def negate(self) -> BigDecimal: ...
    @typing.overload
    def negate(self, mc: MathContext, /) -> BigDecimal: ...
    @typing.overload
    def plus(self) -> BigDecimal: ...
    @typing.overload
    def plus(self, mc: MathContext, /) -> BigDecimal: ...
    @typing.overload
    def pow(self, n: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def pow(self, n: int | java.jint | java.lang.Integer, mc: MathContext, /) -> BigDecimal: ...
    def precision(self) -> int: ...
    @typing.overload
    def remainder(self, divisor: BigDecimal, /) -> BigDecimal: ...
    @typing.overload
    def remainder(self, divisor: BigDecimal, mc: MathContext, /) -> BigDecimal: ...
    def round(self, mc: MathContext, /) -> BigDecimal: ...
    def scale(self) -> int: ...
    def scaleByPowerOfTen(self, n: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def setScale(self, newScale: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def setScale(self, newScale: int | java.jint | java.lang.Integer, roundingMode: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...
    @typing.overload
    def setScale(self, newScale: int | java.jint | java.lang.Integer, roundingMode: RoundingMode, /) -> BigDecimal: ...
    def shortValueExact(self) -> int: ...
    def signum(self) -> int: ...
    def sqrt(self, mc: MathContext, /) -> BigDecimal: ...
    def stripTrailingZeros(self) -> BigDecimal: ...
    @typing.overload
    def subtract(self, subtrahend: BigDecimal, /) -> BigDecimal: ...
    @typing.overload
    def subtract(self, subtrahend: BigDecimal, mc: MathContext, /) -> BigDecimal: ...
    def toBigInteger(self) -> BigInteger: ...
    def toBigIntegerExact(self) -> BigInteger: ...
    def toEngineeringString(self) -> str: ...
    def toPlainString(self) -> str: ...
    def toString(self) -> str: ...
    def ulp(self) -> BigDecimal: ...
    def unscaledValue(self) -> BigInteger: ...
    @typing.overload
    @staticmethod
    def valueOf(val: float | java.jdouble | java.lang.Double, /) -> BigDecimal: ...
    @typing.overload
    @staticmethod
    def valueOf(val: int | java.jlong | java.lang.Long, /) -> BigDecimal: ...
    @typing.overload
    @staticmethod
    def valueOf(unscaledVal: int | java.jlong | java.lang.Long, scale: int | java.jint | java.lang.Integer, /) -> BigDecimal: ...

class BigInteger(java.lang.Comparable[BigInteger], java.lang.Number):
    ONE: typing.ClassVar[BigInteger] = ...
    TEN: typing.ClassVar[BigInteger] = ...
    TWO: typing.ClassVar[BigInteger] = ...
    ZERO: typing.ClassVar[BigInteger] = ...
    @typing.overload
    def __init__(self, val: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, val: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, numBits: int | java.jint | java.lang.Integer, rnd: java.util.Random, /) -> None: ...
    @typing.overload
    def __init__(self, signum: int | java.jint | java.lang.Integer, magnitude: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, val: str | java.lang.String, radix: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, bitLength: int | java.jint | java.lang.Integer, certainty: int | java.jint | java.lang.Integer, rnd: java.util.Random, /) -> None: ...
    @typing.overload
    def __init__(self, val: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, signum: int | java.jint | java.lang.Integer, magnitude: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def abs(self) -> BigInteger: ...
    def add(self, val: BigInteger, /) -> BigInteger: ...
    def andNot(self, val: BigInteger, /) -> BigInteger: ...
    def and_(self, val: BigInteger, /) -> BigInteger: ...
    def bitCount(self) -> int: ...
    def bitLength(self) -> int: ...
    def byteValueExact(self) -> int: ...
    def clearBit(self, n: int | java.jint | java.lang.Integer, /) -> BigInteger: ...
    def compareTo(self, val: BigInteger, /) -> int: ...
    def divide(self, val: BigInteger, /) -> BigInteger: ...
    def divideAndRemainder(self, val: BigInteger, /) -> java.chaquopy.JavaArray[BigInteger]: ...
    def doubleValue(self) -> float: ...
    def equals(self, x: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flipBit(self, n: int | java.jint | java.lang.Integer, /) -> BigInteger: ...
    def floatValue(self) -> float: ...
    def gcd(self, val: BigInteger, /) -> BigInteger: ...
    def getLowestSetBit(self) -> int: ...
    def hashCode(self) -> int: ...
    def intValue(self) -> int: ...
    def intValueExact(self) -> int: ...
    def isProbablePrime(self, certainty: int | java.jint | java.lang.Integer, /) -> bool: ...
    def longValue(self) -> int: ...
    def longValueExact(self) -> int: ...
    def max(self, val: BigInteger, /) -> BigInteger: ...
    def min(self, val: BigInteger, /) -> BigInteger: ...
    def mod(self, m: BigInteger, /) -> BigInteger: ...
    def modInverse(self, m: BigInteger, /) -> BigInteger: ...
    def modPow(self, exponent: BigInteger, m: BigInteger, /) -> BigInteger: ...
    def multiply(self, val: BigInteger, /) -> BigInteger: ...
    def negate(self) -> BigInteger: ...
    def nextProbablePrime(self) -> BigInteger: ...
    def not_(self) -> BigInteger: ...
    def or_(self, val: BigInteger, /) -> BigInteger: ...
    def pow(self, exponent: int | java.jint | java.lang.Integer, /) -> BigInteger: ...
    @staticmethod
    def probablePrime(bitLength: int | java.jint | java.lang.Integer, rnd: java.util.Random, /) -> BigInteger: ...
    def remainder(self, val: BigInteger, /) -> BigInteger: ...
    def setBit(self, n: int | java.jint | java.lang.Integer, /) -> BigInteger: ...
    def shiftLeft(self, n: int | java.jint | java.lang.Integer, /) -> BigInteger: ...
    def shiftRight(self, n: int | java.jint | java.lang.Integer, /) -> BigInteger: ...
    def shortValueExact(self) -> int: ...
    def signum(self) -> int: ...
    def sqrt(self) -> BigInteger: ...
    def sqrtAndRemainder(self) -> java.chaquopy.JavaArray[BigInteger]: ...
    def subtract(self, val: BigInteger, /) -> BigInteger: ...
    def testBit(self, n: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, radix: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def valueOf(val: int | java.jlong | java.lang.Long, /) -> BigInteger: ...
    def xor(self, val: BigInteger, /) -> BigInteger: ...

class MathContext(java.io.Serializable):
    DECIMAL128: typing.ClassVar[MathContext] = ...
    DECIMAL32: typing.ClassVar[MathContext] = ...
    DECIMAL64: typing.ClassVar[MathContext] = ...
    UNLIMITED: typing.ClassVar[MathContext] = ...
    @typing.overload
    def __init__(self, setPrecision: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, val: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, setPrecision: int | java.jint | java.lang.Integer, setRoundingMode: RoundingMode, /) -> None: ...
    def equals(self, x: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPrecision(self) -> int: ...
    def getRoundingMode(self) -> RoundingMode: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class RoundingMode(java.lang.Enum[RoundingMode]):
    CEILING: typing.ClassVar[RoundingMode] = ...
    DOWN: typing.ClassVar[RoundingMode] = ...
    FLOOR: typing.ClassVar[RoundingMode] = ...
    HALF_DOWN: typing.ClassVar[RoundingMode] = ...
    HALF_EVEN: typing.ClassVar[RoundingMode] = ...
    HALF_UP: typing.ClassVar[RoundingMode] = ...
    UNNECESSARY: typing.ClassVar[RoundingMode] = ...
    UP: typing.ClassVar[RoundingMode] = ...
    @typing.overload
    @staticmethod
    def valueOf(rm: int | java.jint | java.lang.Integer, /) -> RoundingMode: ...
    @typing.overload
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> RoundingMode: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[RoundingMode]: ...



import typing

import java
import java.chaquopy
import java.lang
import java.lang.annotation
import java.net
import java.nio
import java.nio.channels
import java.nio.charset
import java.nio.file
import java.security
import java.util
import java.util.stream

class BufferedInputStream(FilterInputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    marklimit: int = ...
    markpos: int = ...
    pos: int = ...
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class BufferedOutputStream(FilterOutputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class BufferedReader(Reader):
    @typing.overload
    def __init__(self, in_: Reader, /) -> None: ...
    @typing.overload
    def __init__(self, in_: Reader, sz: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def lines(self) -> java.util.stream.Stream[java.lang.String]: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readLine(self) -> str | None: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class BufferedWriter(Writer):
    @typing.overload
    def __init__(self, out: Writer, /) -> None: ...
    @typing.overload
    def __init__(self, out: Writer, sz: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def newLine(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, s: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class ByteArrayInputStream(InputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    mark: int = ...
    pos: int = ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readAllBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def readNBytes(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    def transferTo(self, out: OutputStream, /) -> int: ...

class ByteArrayOutputStream(OutputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def reset(self) -> None: ...
    def size(self) -> int: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, hibyte: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def toString(self, charsetName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def toString(self, charset: java.nio.charset.Charset, /) -> str: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def writeTo(self, out: OutputStream, /) -> None: ...

class CharArrayReader(Reader):
    buf: java.chaquopy.JavaArrayJChar = ...
    count: int = ...
    markedPos: int = ...
    pos: int = ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, target: java.nio.CharBuffer, /) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class CharArrayWriter(Writer):
    buf: java.chaquopy.JavaArrayJChar = ...
    count: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> CharArrayWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> CharArrayWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> CharArrayWriter: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def reset(self) -> None: ...
    def size(self) -> int: ...
    def toCharArray(self) -> java.chaquopy.JavaArrayJChar: ...
    def toString(self) -> str: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, c: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeTo(self, out: Writer, /) -> None: ...

class CharConversionException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class Closeable(java.lang.AutoCloseable):
    def close(self) -> None: ...

class Console(Flushable):
    def charset(self) -> java.nio.charset.Charset: ...
    def flush(self) -> None: ...
    def format(self, fmt: str | java.lang.String, /, *args: java.lang.Object) -> Console: ...
    def printf(self, format: str | java.lang.String, /, *args: java.lang.Object) -> Console: ...
    @typing.overload
    def readLine(self) -> str: ...
    @typing.overload
    def readLine(self, fmt: str | java.lang.String, /, *args: java.lang.Object) -> str: ...
    @typing.overload
    def readPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    @typing.overload
    def readPassword(self, fmt: str | java.lang.String, /, *args: java.lang.Object) -> java.chaquopy.JavaArrayJChar: ...
    def reader(self) -> Reader: ...
    def writer(self) -> PrintWriter: ...

class DataInput(java.lang.Object):
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    def readUTF(self) -> str: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def skipBytes(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...

class DataInputStream(DataInput, FilterInputStream):
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    @typing.overload
    def readUTF(self) -> str: ...
    @typing.overload
    @staticmethod
    def readUTF(in_: DataInput, /) -> str: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def skipBytes(self, n: int | java.jint | java.lang.Integer, /) -> int: ...

class DataOutput(java.lang.Object):
    @typing.overload
    def write(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, arg1: str | java.lang.String, /) -> None: ...
    def writeChar(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, arg1: str | java.lang.String, /) -> None: ...
    def writeDouble(self, arg1: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFloat(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeShort(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeUTF(self, arg1: str | java.lang.String, /) -> None: ...

class DataOutputStream(DataOutput, FilterOutputStream):
    written: int = ...
    def __init__(self, out: OutputStream, /) -> None: ...
    def flush(self) -> None: ...
    def size(self) -> int: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, v: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, s: str | java.lang.String, /) -> None: ...
    def writeChar(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, s: str | java.lang.String, /) -> None: ...
    def writeDouble(self, v: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFloat(self, v: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, v: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeShort(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeUTF(self, str: str | java.lang.String, /) -> None: ...

class EOFException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class Externalizable(Serializable):
    def readExternal(self, arg1: ObjectInput, /) -> None: ...
    def writeExternal(self, arg1: ObjectOutput, /) -> None: ...

class File(Serializable, java.lang.Comparable[File]):
    pathSeparator: typing.ClassVar[str] = ...
    pathSeparatorChar: typing.ClassVar[str] = ...
    separator: typing.ClassVar[str] = ...
    separatorChar: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, pathname: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, uri: java.net.URI, /) -> None: ...
    @typing.overload
    def __init__(self, parent: File, child: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, parent: str | java.lang.String, child: str | java.lang.String, /) -> None: ...
    def canExecute(self) -> bool: ...
    def canRead(self) -> bool: ...
    def canWrite(self) -> bool: ...
    def compareTo(self, pathname: File, /) -> int: ...
    def createNewFile(self) -> bool: ...
    @typing.overload
    @staticmethod
    def createTempFile(prefix: str | java.lang.String, suffix: str | java.lang.String, /) -> File: ...
    @typing.overload
    @staticmethod
    def createTempFile(prefix: str | java.lang.String, suffix: str | java.lang.String, directory: File, /) -> File: ...
    def delete(self) -> bool: ...
    def deleteOnExit(self) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def exists(self) -> bool: ...
    def getAbsoluteFile(self) -> File: ...
    def getAbsolutePath(self) -> str: ...
    def getCanonicalFile(self) -> File: ...
    def getCanonicalPath(self) -> str: ...
    def getFreeSpace(self) -> int: ...
    def getName(self) -> str: ...
    def getParent(self) -> str | None: ...
    def getParentFile(self) -> File | None: ...
    def getPath(self) -> str: ...
    def getTotalSpace(self) -> int: ...
    def getUsableSpace(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAbsolute(self) -> bool: ...
    def isDirectory(self) -> bool: ...
    def isFile(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def lastModified(self) -> int: ...
    def length(self) -> int: ...
    @typing.overload
    def list(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @typing.overload
    def list(self, filter: FilenameFilter, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @typing.overload
    def listFiles(self) -> java.chaquopy.JavaArray[File] | None: ...
    @typing.overload
    def listFiles(self, filter: FileFilter, /) -> java.chaquopy.JavaArray[File] | None: ...
    @typing.overload
    def listFiles(self, filter: FilenameFilter, /) -> java.chaquopy.JavaArray[File] | None: ...
    @staticmethod
    def listRoots() -> java.chaquopy.JavaArray[File]: ...
    def mkdir(self) -> bool: ...
    def mkdirs(self) -> bool: ...
    def renameTo(self, dest: File, /) -> bool: ...
    @typing.overload
    def setExecutable(self, executable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setExecutable(self, executable: bool | java.jboolean | java.lang.Boolean, ownerOnly: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setLastModified(self, time: int | java.jlong | java.lang.Long, /) -> bool: ...
    def setReadOnly(self) -> bool: ...
    @typing.overload
    def setReadable(self, readable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setReadable(self, readable: bool | java.jboolean | java.lang.Boolean, ownerOnly: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setWritable(self, writable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setWritable(self, writable: bool | java.jboolean | java.lang.Boolean, ownerOnly: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def toPath(self) -> java.nio.file.Path: ...
    def toString(self) -> str: ...
    def toURI(self) -> java.net.URI: ...
    def toURL(self) -> java.net.URL: ...

class FileDescriptor(java.lang.Object):
    err: typing.ClassVar[FileDescriptor] = ...
    in_: typing.ClassVar[FileDescriptor] = ...
    out: typing.ClassVar[FileDescriptor] = ...
    def __init__(self) -> None: ...
    def sync(self) -> None: ...
    def valid(self) -> bool: ...

class FileFilter(java.lang.Object):
    def accept(self, arg1: File, /) -> bool: ...

class FileInputStream(InputStream):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fdObj: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getChannel(self) -> java.nio.channels.FileChannel: ...
    def getFD(self) -> FileDescriptor: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class FileNotFoundException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class FileOutputStream(OutputStream):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fdObj: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getChannel(self) -> java.nio.channels.FileChannel: ...
    def getFD(self) -> FileDescriptor: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class FilePermission(Serializable, java.security.Permission):
    def __init__(self, path: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...
    def getActions(self) -> str: ...
    def implies(self, p: java.security.Permission, /) -> bool: ...

class FileReader(InputStreamReader):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fd: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...

class FileWriter(OutputStreamWriter):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fd: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class FilenameFilter(java.lang.Object):
    def accept(self, arg1: File, arg2: str | java.lang.String, /) -> bool: ...

class FilterInputStream(InputStream):
    in_: InputStream = ...
    def __init__(self, in_: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class FilterOutputStream(OutputStream):
    out: OutputStream = ...
    def __init__(self, out: OutputStream, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class FilterReader(Reader):
    in_: Reader = ...
    def __init__(self, in_: Reader, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class FilterWriter(Writer):
    out: Writer = ...
    def __init__(self, out: Writer, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class Flushable(java.lang.Object):
    def flush(self) -> None: ...

class IOError(java.lang.Error):
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...

class IOException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class InputStream(Closeable):
    def __init__(self) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @staticmethod
    def nullInputStream() -> InputStream: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readAllBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def readNBytes(self, len: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def readNBytes(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    def skipNBytes(self, n: int | java.jlong | java.lang.Long, /) -> None: ...
    def transferTo(self, out: OutputStream, /) -> int: ...

class InputStreamReader(Reader):
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, charsetName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, cs: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, dec: java.nio.charset.CharsetDecoder, /) -> None: ...
    def close(self) -> None: ...
    def getEncoding(self) -> str: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, target: java.nio.CharBuffer, /) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...

class InterruptedIOException(IOException):
    bytesTransferred: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class InvalidClassException(ObjectStreamException):
    classname: str = ...
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cname: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...
    def getMessage(self) -> str: ...

class InvalidObjectException(ObjectStreamException):
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class LineNumberInputStream(FilterInputStream):
    def __init__(self, in_: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def getLineNumber(self) -> int: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def setLineNumber(self, lineNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class LineNumberReader(BufferedReader):
    @typing.overload
    def __init__(self, in_: Reader, /) -> None: ...
    @typing.overload
    def __init__(self, in_: Reader, sz: int | java.jint | java.lang.Integer, /) -> None: ...
    def getLineNumber(self) -> int: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readLine(self) -> str: ...
    def reset(self) -> None: ...
    def setLineNumber(self, lineNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class NotActiveException(ObjectStreamException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class NotSerializableException(ObjectStreamException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, classname: str | java.lang.String, /) -> None: ...

class ObjectInput(DataInput, java.lang.AutoCloseable):
    def available(self) -> int: ...
    def close(self) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def readObject(self) -> java.lang.Object: ...
    def skip(self, arg1: int | java.jlong | java.lang.Long, /) -> int: ...

class ObjectInputStream(InputStream, ObjectInput, ObjectStreamConstants):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def defaultReadObject(self) -> None: ...
    def enableResolveObject(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readClassDescriptor(self) -> ObjectStreamClass: ...
    def readDouble(self) -> float: ...
    def readFields(self) -> ObjectInputStream.GetField: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readObject(self) -> java.lang.Object: ...
    def readObjectOverride(self) -> java.lang.Object: ...
    def readShort(self) -> int: ...
    def readStreamHeader(self) -> None: ...
    def readUTF(self) -> str: ...
    def readUnshared(self) -> java.lang.Object: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def registerValidation(self, obj: ObjectInputValidation, prio: int | java.jint | java.lang.Integer, /) -> None: ...
    def resolveClass(self, desc: ObjectStreamClass, /) -> typing.Type[java.lang.Object]: ...
    def resolveObject(self, obj: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
    def resolveProxyClass(self, interfaces: java.chaquopy.JavaArray[java.lang.String], /) -> typing.Type[java.lang.Object]: ...
    def skipBytes(self, len: int | java.jint | java.lang.Integer, /) -> int: ...

    class GetField(java.lang.Object):
        def __init__(self) -> None: ...
        def defaulted(self, arg1: str | java.lang.String, /) -> bool: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jbyte | java.lang.Byte, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: str | java.jchar | java.lang.Character, /) -> str: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> float: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> float: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jshort | java.lang.Short, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def getObjectStreamClass(self) -> ObjectStreamClass: ...

class ObjectInputValidation(java.lang.Object):
    def validateObject(self) -> None: ...

class ObjectOutput(DataOutput, java.lang.AutoCloseable):
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeObject(self, arg1: java.lang.Object | int | bool | float | str, /) -> None: ...

class ObjectOutputStream(ObjectOutput, ObjectStreamConstants, OutputStream):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    def annotateClass(self, cl: typing.Type[java.lang.Object], /) -> None: ...
    def annotateProxyClass(self, cl: typing.Type[java.lang.Object], /) -> None: ...
    def close(self) -> None: ...
    def defaultWriteObject(self) -> None: ...
    def drain(self) -> None: ...
    def enableReplaceObject(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def flush(self) -> None: ...
    def putFields(self) -> ObjectOutputStream.PutField: ...
    def replaceObject(self, obj: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
    def reset(self) -> None: ...
    def useProtocolVersion(self, version: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, val: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, str: str | java.lang.String, /) -> None: ...
    def writeChar(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, str: str | java.lang.String, /) -> None: ...
    def writeClassDescriptor(self, desc: ObjectStreamClass, /) -> None: ...
    def writeDouble(self, val: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFields(self) -> None: ...
    def writeFloat(self, val: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, val: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeObject(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    def writeObjectOverride(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    def writeShort(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeStreamHeader(self) -> None: ...
    def writeUTF(self, str: str | java.lang.String, /) -> None: ...
    def writeUnshared(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...

    class PutField(java.lang.Object):
        def __init__(self) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jbyte | java.lang.Byte, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: str | java.jchar | java.lang.Character, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jshort | java.lang.Short, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def write(self, arg1: ObjectOutput, /) -> None: ...

class ObjectStreamClass(Serializable):
    NO_FIELDS: typing.ClassVar[java.chaquopy.JavaArray[ObjectStreamField]] = ...
    def forClass(self) -> typing.Type[java.lang.Object]: ...
    def getField(self, name: str | java.lang.String, /) -> ObjectStreamField: ...
    def getFields(self) -> java.chaquopy.JavaArray[ObjectStreamField]: ...
    def getName(self) -> str: ...
    def getSerialVersionUID(self) -> int: ...
    @staticmethod
    def lookup(cl: typing.Type[java.lang.Object], /) -> ObjectStreamClass: ...
    @staticmethod
    def lookupAny(cl: typing.Type[java.lang.Object], /) -> ObjectStreamClass: ...
    def toString(self) -> str: ...

class ObjectStreamConstants(java.lang.Object):
    PROTOCOL_VERSION_1: typing.ClassVar[int] = ...
    PROTOCOL_VERSION_2: typing.ClassVar[int] = ...
    SC_BLOCK_DATA: typing.ClassVar[int] = ...
    SC_ENUM: typing.ClassVar[int] = ...
    SC_EXTERNALIZABLE: typing.ClassVar[int] = ...
    SC_SERIALIZABLE: typing.ClassVar[int] = ...
    SC_WRITE_METHOD: typing.ClassVar[int] = ...
    STREAM_MAGIC: typing.ClassVar[int] = ...
    STREAM_VERSION: typing.ClassVar[int] = ...
    SUBCLASS_IMPLEMENTATION_PERMISSION: typing.ClassVar[SerializablePermission] = ...
    SUBSTITUTION_PERMISSION: typing.ClassVar[SerializablePermission] = ...
    TC_ARRAY: typing.ClassVar[int] = ...
    TC_BASE: typing.ClassVar[int] = ...
    TC_BLOCKDATA: typing.ClassVar[int] = ...
    TC_BLOCKDATALONG: typing.ClassVar[int] = ...
    TC_CLASS: typing.ClassVar[int] = ...
    TC_CLASSDESC: typing.ClassVar[int] = ...
    TC_ENDBLOCKDATA: typing.ClassVar[int] = ...
    TC_ENUM: typing.ClassVar[int] = ...
    TC_EXCEPTION: typing.ClassVar[int] = ...
    TC_LONGSTRING: typing.ClassVar[int] = ...
    TC_MAX: typing.ClassVar[int] = ...
    TC_NULL: typing.ClassVar[int] = ...
    TC_OBJECT: typing.ClassVar[int] = ...
    TC_PROXYCLASSDESC: typing.ClassVar[int] = ...
    TC_REFERENCE: typing.ClassVar[int] = ...
    TC_RESET: typing.ClassVar[int] = ...
    TC_STRING: typing.ClassVar[int] = ...
    baseWireHandle: typing.ClassVar[int] = ...

class ObjectStreamException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class ObjectStreamField(java.lang.Comparable[java.lang.Object]):
    @typing.overload
    def __init__(self, name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, type: typing.Type[java.lang.Object], unshared: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def compareTo(self, obj: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getName(self) -> str: ...
    def getOffset(self) -> int: ...
    def getType(self) -> typing.Type[java.lang.Object]: ...
    def getTypeCode(self) -> str: ...
    def getTypeString(self) -> str: ...
    def isPrimitive(self) -> bool: ...
    def isUnshared(self) -> bool: ...
    def setOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...

class OptionalDataException(ObjectStreamException):
    eof: bool = ...
    length: int = ...

class OutputStream(Closeable, Flushable):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @staticmethod
    def nullOutputStream() -> OutputStream: ...
    @typing.overload
    def write(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class OutputStreamWriter(Writer):
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, charsetName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, cs: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, enc: java.nio.charset.CharsetEncoder, /) -> None: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> Writer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> Writer: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getEncoding(self) -> str: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PipedInputStream(InputStream):
    PIPE_SIZE: typing.ClassVar[int] = ...
    buffer: java.chaquopy.JavaArrayJByte = ...
    in_: int = ...
    out: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedOutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedOutputStream, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def connect(self, src: PipedOutputStream, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def receive(self, b: int | java.jint | java.lang.Integer, /) -> None: ...

class PipedOutputStream(OutputStream):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, snk: PipedInputStream, /) -> None: ...
    def close(self) -> None: ...
    def connect(self, snk: PipedInputStream, /) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PipedReader(Reader):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedWriter, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedWriter, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def connect(self, src: PipedWriter, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...

class PipedWriter(Writer):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, snk: PipedReader, /) -> None: ...
    def close(self) -> None: ...
    def connect(self, snk: PipedReader, /) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PrintStream(FilterOutputStream, Closeable, java.lang.Appendable):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, encoding: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> PrintStream: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> PrintStream: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> PrintStream: ...
    def checkError(self) -> bool: ...
    def clearError(self) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def format(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def format(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def print_(self, c: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def print_(self, d: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def print_(self, f: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def print_(self, i: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def print_(self, l: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def print_(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def print_(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def print_(self, b: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def print_(self, s: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def printf(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def printf(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def println(self) -> None: ...
    @typing.overload
    def println(self, x: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def println(self, x: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def println(self, x: str | java.lang.String, /) -> None: ...
    @typing.overload
    def println(self, x: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def println(self, x: java.chaquopy.JavaArrayJChar, /) -> None: ...
    def setError(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...

class PrintWriter(Writer):
    out: Writer = ...
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: Writer, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, out: Writer, autoFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> PrintWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> PrintWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> PrintWriter: ...
    def checkError(self) -> bool: ...
    def clearError(self) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def format(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def format(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def print_(self, c: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def print_(self, d: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def print_(self, f: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def print_(self, i: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def print_(self, l: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def print_(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def print_(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def print_(self, b: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def print_(self, s: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def printf(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def printf(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def println(self) -> None: ...
    @typing.overload
    def println(self, x: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def println(self, x: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def println(self, x: str | java.lang.String, /) -> None: ...
    @typing.overload
    def println(self, x: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def println(self, x: java.chaquopy.JavaArrayJChar, /) -> None: ...
    def setError(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def write(self, s: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PushbackInputStream(FilterInputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    pos: int = ...
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def unread(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def unread(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def unread(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PushbackReader(FilterReader):
    @typing.overload
    def __init__(self, in_: Reader, /) -> None: ...
    @typing.overload
    def __init__(self, in_: Reader, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def unread(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def unread(self, cbuf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def unread(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class RandomAccessFile(Closeable, DataInput, DataOutput):
    @typing.overload
    def __init__(self, file: File, mode: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, mode: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getChannel(self) -> java.nio.channels.FileChannel: ...
    def getFD(self) -> FileDescriptor: ...
    def getFilePointer(self) -> int: ...
    def length(self) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    def readUTF(self) -> str: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def seek(self, pos: int | java.jlong | java.lang.Long, /) -> None: ...
    def setLength(self, newLength: int | java.jlong | java.lang.Long, /) -> None: ...
    def skipBytes(self, n: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, v: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, s: str | java.lang.String, /) -> None: ...
    def writeChar(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, s: str | java.lang.String, /) -> None: ...
    def writeDouble(self, v: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFloat(self, v: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, v: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeShort(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeUTF(self, str: str | java.lang.String, /) -> None: ...

class Reader(Closeable, java.lang.Readable):
    lock: java.lang.Object = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, lock: java.lang.Object | int | bool | float | str, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @staticmethod
    def nullReader() -> Reader: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, target: java.nio.CharBuffer, /) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    def transferTo(self, out: Writer, /) -> int: ...

class SequenceInputStream(InputStream):
    @typing.overload
    def __init__(self, e: java.util.Enumeration[InputStream], /) -> None: ...
    @typing.overload
    def __init__(self, s1: InputStream, s2: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...

class Serial(java.lang.annotation.Annotation): ...

class Serializable(java.lang.Object): ...

class SerializablePermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...

class StreamCorruptedException(ObjectStreamException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class StreamTokenizer(java.lang.Object):
    TT_EOF: typing.ClassVar[int] = ...
    TT_EOL: typing.ClassVar[int] = ...
    TT_NUMBER: typing.ClassVar[int] = ...
    TT_WORD: typing.ClassVar[int] = ...
    nval: float = ...
    sval: str = ...
    ttype: int = ...
    @typing.overload
    def __init__(self, is_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, r: Reader, /) -> None: ...
    def commentChar(self, ch: int | java.jint | java.lang.Integer, /) -> None: ...
    def eolIsSignificant(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def lineno(self) -> int: ...
    def lowerCaseMode(self, fl: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def nextToken(self) -> int: ...
    def ordinaryChar(self, ch: int | java.jint | java.lang.Integer, /) -> None: ...
    def ordinaryChars(self, low: int | java.jint | java.lang.Integer, hi: int | java.jint | java.lang.Integer, /) -> None: ...
    def parseNumbers(self) -> None: ...
    def pushBack(self) -> None: ...
    def quoteChar(self, ch: int | java.jint | java.lang.Integer, /) -> None: ...
    def resetSyntax(self) -> None: ...
    def slashSlashComments(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def slashStarComments(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toString(self) -> str: ...
    def whitespaceChars(self, low: int | java.jint | java.lang.Integer, hi: int | java.jint | java.lang.Integer, /) -> None: ...
    def wordChars(self, low: int | java.jint | java.lang.Integer, hi: int | java.jint | java.lang.Integer, /) -> None: ...

class StringBufferInputStream(InputStream):
    buffer: str = ...
    count: int = ...
    pos: int = ...
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    def available(self) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class StringReader(Reader):
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, ns: int | java.jlong | java.lang.Long, /) -> int: ...

class StringWriter(Writer):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> StringWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> StringWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> StringWriter: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getBuffer(self) -> java.lang.StringBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class SyncFailedException(IOException):
    def __init__(self, desc: str | java.lang.String, /) -> None: ...

class UTFDataFormatException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class UncheckedIOException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self, cause: IOException, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: IOException, /) -> None: ...
    def getCause(self) -> IOException: ...

class UnsupportedEncodingException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class WriteAbortedException(ObjectStreamException):
    detail: java.lang.Exception = ...
    def __init__(self, s: str | java.lang.String, ex: java.lang.Exception, /) -> None: ...
    def getCause(self) -> java.lang.Throwable: ...
    def getMessage(self) -> str: ...

class Writer(Closeable, Flushable, java.lang.Appendable):
    lock: java.lang.Object = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, lock: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> Writer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> Writer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> Writer: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @staticmethod
    def nullWriter() -> Writer: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.content
import android.os
import java
import java.lang
import java.util.concurrent

class AppSetId(java.lang.Object):
    SCOPE_APP: typing.ClassVar[int] = ...
    SCOPE_DEVELOPER: typing.ClassVar[int] = ...
    def __init__(self, appSetId: str | java.lang.String, appSetIdScope: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getId(self) -> str: ...
    def getScope(self) -> int: ...
    def hashCode(self) -> int: ...

class AppSetIdManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> AppSetIdManager: ...
    def getAppSetId(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[AppSetId, java.lang.Exception], /) -> None: ...
